package it.polimi.dei.esercitazioniIngegneriaDelSoftware.swing.calculator.handlers;

import java.awt.event.ActionListener;

import it.polimi.dei.esercitazioniIngegneriaDelSoftware.swing.calculator.controller.CalculatorController;
import it.polimi.dei.esercitazioniIngegneriaDelSoftware.swing.calculator.model.Operation;

/**
 * Factory per la creazione di handler che delegano la gestione
 * degli eventi al Controller.
 * @author Andrea Mocci
 *
 */
public class ControllerHandlerFactory {

  private final CalculatorController controller;
  
  /**
   * Crea una nuova factory che crea handler che delegano
   * la gestione degli eventi al controller
   * @param controller un controller
   */
  public ControllerHandlerFactory(CalculatorController controller) {
    this.controller = controller;
  }
  
  /**
   * Crea un handler per la gestione di una operazione.
   * @param operation l'operazione da gestire
   * @return un {@link ActionListener} che delega l'evento
   * di selezione di una operazione al controller.
   */
  public ActionListener operationButtonHandler(Operation operation) {
    return new OperationButtonHandler(controller, operation);
  }
  
  /**
   * Crea un handler per la gestione della richiesta di esecuzione
   * di una operazione (equals)
   * @return un {@link ActionListener} che delega la gestione dell'evento
   * al controller.
   */
  public ActionListener equalsButtonHandler() {
    return new EqualsButtonHandler(controller);
  }
  
  /**
   * Crea un handler per la gestione della richiesta
   * di reset della calcolatrice.
   * @return un {@link ActionListener} che delega la
   * gestione dell'evento al controller.
   */
  public ActionListener cancelButtonHandler() {
    return new CancelButtonHandler(controller);
  }
 
  /**
   * Un handler per la gestione della richiesta di aggiunta 
   * di una cifra all'operando
   * @return un {@link ActionListener} che delega al controller 
   * la gestione della richiesta di aggiunta di una cifra all'operando
   */
  public ActionListener digitButtonHandler() {
    return new DigitsButtonControllerHandler(controller);
  }
}
