package it.polimi.dei.esercitazioniIngegneriaDelSoftware.swing.calculator.handlers;

import java.awt.event.ActionListener;

import it.polimi.dei.esercitazioniIngegneriaDelSoftware.swing.calculator.view.CalculatorGUI;

/**
 * Factory per la creazione di handler per gli eventi che
 * determinano cambiamenti semplici solo nella gui.
 * @author Andrea Mocci
 *
 */
public class GuiHandlerFactory {

  private final CalculatorGUI gui;
  
  /**
   * Crea una factory per una determinata gui.
   * @param gui una graphical user interface.
   */
  public GuiHandlerFactory(CalculatorGUI gui) {
    this.gui = gui;
  }
  
  /**
   * Costruisce l'handler per il pulsante di virgola.
   * @return un {@link ActionListener} che rappresenta l'azione da eseguire
   * quando e' premuto il pulsante virgola.
   */
  public ActionListener dotButtonHandler() {
    return new DotButtonHandler(gui);
  }

  /**
   * Costruisce l'handler per il pulsante di una cifra.
   * @param digitModelButtonHandler L'handler del controller che si preoccupa
   * di cambiare lo stato del modello.
   * @param digit la cifra corrispondente all'handler.
   * @return un {@link ActionListener} che racchiude l'azione da eseguire
   * quando e' premuto un pulsante cifra. E' delegato a questo handler
   * chiamare <code>digitModelButtonHandler</code>.
   */
  public ActionListener digitButtonHandler(ActionListener digitModelButtonHandler,
      int digit) {
    return new DigitsButtonGuiHandler(gui,digitModelButtonHandler, digit);
  }
  
}
