package it.polimi.dei.esercitazioniIngegneriaDelSoftware.swing.calculator.model;

/**
 * Rappresenta un evento che abilita o disabilita un
 * insieme di operazioni nella calcolatrice.
 * 
 * @author Andrea Mocci
 *
 */
public class CalculatorEnableEvent implements CalculatorModelEvent {

  /**
   * Rappresenta un insieme di operazioni nella calcolatrice.
   * @author andrea
   *
   */
  public enum Target { 
    /**
     *  Rappresenta la possibilita' di inserire
     *  operandi tramite cifre.
     */ 
    OPERAND,
     /**
      * Rappresenta la possibilita' di eseguire 
      * una operazione.
      */ 
    EQUALS
  }
  
  private final Target target;
  private final boolean enabled;
  
  /**
   * Crea un nuovo evento di abilitazione di un insieme di operazioni.
   * @param target il target di questo evento.
   * @param enabled <code>true</code> se l'evento abilita l'operazione,
   * <code>false</code> se lo disabilita.
   */
  CalculatorEnableEvent(Target target, boolean enabled) {
    this.target = target;
    this.enabled = enabled;
  }
  
  /**
   * Restituisce il target di questo evento.
   * @return un insieme di operazioni relative a questo evento.
   */
  public Target getTarget() {
    return this.target;
  }
  
  /**
   * Rappresenta il fatto che l'evento abiliti o disabiliti l'insieme
   * di operazioni.
   * @return <code>true</code> se l'evento rappresenta l'abilitazione
   * dell'insieme di operazione, <code>false</code> altrimenti.
   */
  public boolean isEnabled() {
    return this.enabled;
  }
  
  @Override
  public String representation() {
    return "EnableEvent: " + target.name() +
        " is " + (enabled ? "" : "not ") + "enabled";
  }

}
