package it.polimi.dei.esercitazioniIngegneriaDelSoftware.swing.calculator.model;

import it.polimi.dei.esercitazioniIngegneriaDelSoftware.swing.calculator.model.CalculatorEnableEvent.Target;

/**
 * Incapsula factory methods per la creazione di eventi del modello.
 * @author Andrea Mocci
 *
 */
public final class CalculatorModelEventFactory {

  /** rende la classe non istanziabile */
  private CalculatorModelEventFactory() {}
  
  /**
   * Costruisce un evento che rappresenta l'avvenuto calcolo di un risultato.
   * @param result il risultato calcolato.
   * @return un evento che rappresenta il risultato calcolato.
   */
  public static CalculatorModelEvent resultEvent(double result) {
    return new CalculatorResultEvent(result);
  }
  
  /**
   * Costruisce un evento che rappresenta l'abilitazione di un
   * determinato insieme di operazioni.
   * @param target l'insieme di operazioni legato a questo evento
   * @param enabled <code>true</code> se l'evento rappresenta una
   * abilitazione, <code>false</code> altrimenti.
   * @return un evento di abilitazione corrispondente ai parametri scelti.
   */
  public static CalculatorEnableEvent enableEvent(Target target, boolean enabled) {
    return new CalculatorEnableEvent(target, enabled);
  }
  
}
